# PDT: Pipeline Decision Transformer

![arch](./arch.png)
<p align="center"><font size=4>Framework Architecture</font></p> 

## TODO
  - [ ] Pipeline model with data scheduler
  - [ ] Performance experiments
  - [ ] Decoupling components from starcraft
  
  
